.. _api:

mccli package
=============

.. _cli:

CLI
----

.. toctree::
  :maxdepth: 2

  api/cli/mccli
  api/cli/info
  api/cli/ssh
  api/cli/scp
  api/cli/sftp
  

Utils
----------

.. toctree::
  :maxdepth: 2

  api/utils/mccli.motley_cue_client
  api/utils/mccli.ssh_wrapper
  api/utils/mccli.click_utils
  api/utils/mccli.info_utils
  api/utils/mccli.init_utils
  api/utils/mccli.scp_utils

